@@ -1,4 +1,4 @@
-from .xlsxio_read import (  # noqa:F401
+from ._xlsxio import (  # noqa:F401
     # Flags to determine how data is processed
     XLSXIOREAD_SKIP_NONE,
     XLSXIOREAD_SKIP_EMPTY_ROWS,
@@ -12,4 +12,4 @@ from .xlsxio_read import (  # noqa:F401
     XlsxioReader,
 )
 
-del xlsxio_read  # noqa:F821
+del _xlsxio  # noqa:F821
